django-lb-adminlte
==================

.. image:: https://secure.travis-ci.org/vicalloy/django-lb-adminlte.svg?branch=master
   :target: http://travis-ci.org/vicalloy/django-lb-adminlte

.. image:: https://img.shields.io/pypi/v/django-lb-adminlte.svg
   :target: https://pypi.python.org/pypi/django-lb-adminlte/
   :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-lb-adminlte.svg
   :target: https://pypi.python.org/pypi/django-lb-adminlte/
   :alt: Number of PyPI downloads

Reusable AdminLTE templates library for Django.